"""UI components for displaying and handling user input."""

from quli_quiz.ui.display import display_question, display_results
from quli_quiz.ui.input import get_answer_interactive, get_answer_simple

__all__ = ["display_question", "display_results", "get_answer_interactive", "get_answer_simple"]

